/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Communities System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@silcom.com>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2001 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.venice.servlets.format.sideboxes;

import java.io.*;
import java.util.*;
import org.w3c.dom.*;
import com.silverwrist.util.DOMElementHelper;
import com.silverwrist.util.StringUtil;
import com.silverwrist.venice.core.*;
import com.silverwrist.venice.servlets.format.*;

public class JSPSideBoxFactory implements SideBoxFactory
{
  /*--------------------------------------------------------------------------------
   * Attributes
   *--------------------------------------------------------------------------------
   */

  private String title;                   // title of sidebox for logged-in users
  private String anon_title;              // title of sidebox for not-logged-in users
  private String format_jsp;              // name of formatting JSP file
  private Map strings;                    // the strings we can access from the JSP page

  /*--------------------------------------------------------------------------------
   * Constructor
   *--------------------------------------------------------------------------------
   */

  public JSPSideBoxFactory()
  { // do nothing
  } // end constructor

  /*--------------------------------------------------------------------------------
   * Internal functions
   *--------------------------------------------------------------------------------
   */

  String getTitle(boolean logged_in)
  {
    return (logged_in ? title : anon_title);

  } // end getTitle

  String getTargetJSPName()
  {
    return format_jsp;

  } // end getTargetJSPName

  String getString(String key)
  {
    return (String)(strings.get(key));

  } // end getString

  String replaceStrings(String base)
  {
    return StringUtil.replaceAllVariables(base,strings);

  } // end replaceStrings

  /*--------------------------------------------------------------------------------
   * Implementations from interface SideBoxFactory
   *--------------------------------------------------------------------------------
   */

  public void setConfiguration(Element cfg) throws ConfigException
  {
    DOMElementHelper cfg_h = new DOMElementHelper(cfg);
    title = cfg_h.getSubElementText("title");
    if (title==null)
      throw new ConfigException("no <title/> specified for sidebox",cfg);
    title += ":";
    anon_title = cfg_h.getSubElementText("anon-title");
    if (anon_title==null)
      anon_title = title;
    else
      anon_title += ":";

    format_jsp = cfg_h.getSubElementText("format-jsp");
    if (format_jsp==null)
      throw new ConfigException("no <format-jsp/> specified for sidebox",cfg);

    Element s = cfg_h.getSubElement("strings");
    if (s!=null)
    { // we've got some replacement strings to add
      HashMap tmp = new HashMap();
      NodeList sl = s.getChildNodes();
      for (int i=0; i<sl.getLength(); i++)
      { // get all the replacement strings and add them to the map
	Node n = sl.item(i);
	if (n.getNodeType()==Node.ELEMENT_NODE)
	{ // get the text inside this subelement and save it off
	  DOMElementHelper s_h = new DOMElementHelper((Element)n);
	  tmp.put(n.getNodeName(),s_h.getElementText());

	} // end if

      } // end for

      strings = Collections.unmodifiableMap(tmp);

    } // end if
    else // no replacement strings
      strings = Collections.EMPTY_MAP;

  } // end setConfiguration

  public VeniceContent create(VeniceEngine engine, UserContext uc)
  {
    return new JSPSideBox(this,engine,uc);

  } // end create

} // end class JSPSideBoxFactory
